from typing import List
from .metrics import Metrics
from datetime import datetime


class SessionMetrics:
    def __init__(self):
        self.signal_readings: List[float] = []
        self.bitrate_readings: List[float] = []
        self.start_time = datetime.now()

    def add_metrics(self, metrics: Metrics):
        try:
            self.signal_readings.append(float(metrics.signal_strength))
            self.bitrate_readings.append(float(metrics.bitrate))
        except ValueError:
            print("Warning: Invalid metrics value encountered")

    def get_session_summary(self) -> str:
        if not self.signal_readings or not self.bitrate_readings:
            return "No data collected in this session"

        avg_signal = sum(self.signal_readings) / len(self.signal_readings)
        avg_bitrate = sum(self.bitrate_readings) / len(self.bitrate_readings)

        duration = datetime.now() - self.start_time
        minutes = duration.total_seconds() / 60

        return (
            f"Session Summary:\n"
            f"Duration: {minutes:.1f} minutes\n"
            f"Average Signal: {avg_signal:.1f} dBm\n"
            f"Average Bitrate: {avg_bitrate:.1f} Mb/s\n"
            f"Samples collected: {len(self.signal_readings)}"
        )
